@@ -1,32 +1,28 @@
 """
     toolkit_library.inspector
-    ~~~~~~~~~~~~~~~~~~~~~~~~
-    Inspect functions in a module and invoke them
-    Notice:
-        method name promption used raw_input
-        method parameter promption used input
-        Python3 raw_input becomes input and input disappears. If you want input, you can use eval(raw_input)
+    ~~~~~~~~~~~~~~~~~~~~~~~~~
+    Inspect a module or a package, get information of modules, methods and classes.
 """
-import inspect
+import inspect, pkgutil
 
 
 class ModuleInspector(object):
-    """Inspect the functions in a module for invoking
-    Sample usage:
-        inspector = ModuleInspector(module)
-        inspector.invoke() # inspect the available functions and invoke one
-        inspector.invoke('foo') # invoke function foo in module
-        inspector.invoke('bar', 'hello') # invoke function bar in module and provide one argument 'hello'
-    If no function name was specified, you will be prompted to specify one;
-    If not enough arguments were specified, you will be prompted to specify them.
-    """
+    """For inspecting a module."""
     def __init__(self, module):
         if not inspect.ismodule(module):
             raise TypeError('{0} is not a valid python module'.format(module))
         self.module = module
 
     def invoke(self, function_name = None, *args):
-        """Invoke a function of the module"""
+        """Inspect the functions in a module for invoking
+        Sample usage:
+            inspector = ModuleInspector(module)
+            inspector.invoke() # inspect the available functions and invoke one
+            inspector.invoke('foo') # invoke function foo in module
+            inspector.invoke('bar', 'hello') # invoke function bar in module and provide one argument 'hello'
+        If no function name was specified, you will be prompted to specify one;
+        If not enough arguments were specified, you will be prompted to specify them.
+        """
         predicate = inspect.isfunction
         if not function_name:
             print 'The following functions are available in {0}:'.format(self.module.__file__)
@@ -68,3 +64,21 @@ class ModuleInspector(object):
     def import_all_classes_statement(self):
        """The statement for Importing all of the classes in the module"""
        return 'from {0} import {1}'.format(self.module.__name__, ', '.join(self.get_all_classes()))
+
+
+class PackageInspector(object):
+    """For inspecting a package"""
+    def __init__(self, package):
+        if not PackageInspector.is_package(package):
+            raise TypeError('{0} is not a valid python package'.format(package))
+        self.package = package
+
+    @staticmethod
+    def is_package(package):
+        """Return True is the parameter package is a Python package"""
+        return inspect.ismodule(package) and (package.__file__.endswith('__init__.py') or package.__file__.endswith('__init__.pyc'))
+
+    def get_all_modules(self):
+        """Return all of the module names in the package as a list"""
+        members = pkgutil.iter_modules(self.package.__path__)
+        return [name for _, name, _ in members]
